==> maxdb-all-sun-64bit-sparc-7_6_00_27.tgz: SAPDB/Install/Wizard/Dialog/Summary.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V76/c_00/b_27/sys/src/install/perl/SAPDB/Install/Wizard/Dialog/Summary.pm#1 $
# $DateTime: 2006/04/27 14:44:55 $
# $Change: 124736 $
#
# Desc: Installation summary 
# 
#

package SAPDB::Install::Wizard::Dialog::Summary;

use Wx qw (
	wxALL wxVERTICAL wxEXPAND);

use SAPDB::Install::Tools;

use base SAPDB::Install::Wizard::Dialog::Base;

sub new {
	my ($this) = shift->SUPER::new(@_);
	return $this;
}



sub init{
	my ($self,$config) = @_;
	my $sizer = Wx::BoxSizer->new(wxVERTICAL);
	$self->SetSizer($sizer);
	$self->{'initialized'} = 1;
	return {'auto_next' => 1};
}


sub Process{
	my ($self,$config) = @_;
	return {} if $self->{'activated'};
	$self->{'current_package'} = undef;
	$self->GetWizard->SetInstallMode(1);
	$self->{'tree_ctrl'} = Wx::TreeCtrl->new($self,-1,[0,0],[350,300]);
	my $index = 0;
	$self->{'root_node'} = $self->{'tree_ctrl'}->AddRoot('MaxDB Installation',-1,-1);
	$self->{'tree_ctrl'}->SetItemBold($self->{'root_node'},1);

	#
	#	Database Settings
	#	
	
	if(defined $config->{'container'}->Template){
		my $node = $self->{'tree_ctrl'}->AppendItem($self->{'root_node'},'Database ['.
		$config->{'container'}->Template->getDBInstance()->getDBName().']',-1,-1);
		$self->{'tree_ctrl'}->SetItemBold($node,1);
		foreach my $frame (@{$config->{'container'}->Template->createTemplateOverView}){
			my $node = $self->{'tree_ctrl'}->AppendItem($node,$frame->{'Title'},-1,-1);				
			$self->{'tree_ctrl'}->SetItemBold($node,1);
			foreach my $param (sort { $frame->{'Data'}->{$a}->{'ControlType'}->{'priority'} <=>
									  $frame->{'Data'}->{$b}->{'ControlType'}->{'priority'} }
							   keys(%{$frame->{'Data'}})){
					
					
					my $value = &{$frame->{'Data'}->{$param}->{'Getter'}};
					if($frame->{'Data'}->{$param}->{'ControlType'}->{'id'} eq 'pagesType' ||
						$frame->{'Data'}->{$param}->{'ControlType'}->{'unit'} eq 'pages'){
						$value = (int ($value * 8 / 1024)).' MB';
					}
					elsif($frame->{'Data'}->{$param}->{'ControlType'}->{'id'} eq 'booleanType'){
						$value = ($value ? 'On' : 'Off');
					}
					
					my $node = $self->{'tree_ctrl'}->AppendItem($node,$frame->{'Data'}->{$param}->{'Label'}.': '.
													$value,-1,-1);				
					
					#my %desc = (
					#				'label' => $frame->{'Data'}->{$param}->{'Label'},
					#				'value' => &{$frame->{'Data'}->{$param}->{'Getter'}},
					#				'desc'  => $frame->{'Data'}->{$param}->{'Description'}
					#			);
			}
			$self->{'tree_ctrl'}->Expand($node) if $frame->{'SummaryExpand'};	
		}
		$self->{'tree_ctrl'}->Expand($node);
	}
	elsif(defined $config->{'dbupdate'}){
		my $node = $self->{'tree_ctrl'}->AppendItem($self->{'root_node'},'Update Database ['.
		$config->{'dbupdate'}->{'dbname'}.']',-1,-1);
		$self->{'tree_ctrl'}->SetItemBold($node,1);
		if(defined $config->{'dbupdate'}->{'registry_instancedata'}){
			foreach my $param (sort keys(%{$config->{'dbupdate'}->{'registry_instancedata'}})){
				next if $param =~ /INSTANCE_CHECK/;
				my $value = $config->{'dbupdate'}->{'registry_instancedata'}->{$param};
				if($param =~ /OK/){
					if($value){
						$value = 'yes';
					}
					else{
						$value = 'no';
					}
				}
				elsif($value !~ /\S/){
					next;	
				}
				if($param =~ /SOFTWARE_OK/){
					$param = 'Software already installed';
				}
				if($param =~ /^TYPE$/){
					$param = 'Database Type';
				}									
				$param =~ s/_/\ /g;
				$param =~ tr/A-Z/a-z/;
				$param =~ s/^(\w)/\u$1/g;
				$param =~ s/\s(\w)/\ \u$1/g;
				
				my $node = $self->{'tree_ctrl'}->AppendItem($node,$param.': '.
							$value,-1,-1);		
			}
			
		}
		
	}

	my $node = $self->{'tree_ctrl'}->AppendItem($self->{'root_node'},'Software',-1,-1);
	$self->{'tree_ctrl'}->SetItemBold($node,1);

	
	#
	#	software components
	#
	
	my $dependent_path;

	my $package_count = 0;

	unless(defined $config->{'dbupdate'} and
		defined $config->{'dbupdate'}->{'registry_instancedata'} and 
		$config->{'dbupdate'}->{'registry_instancedata'}->{'SOFTWARE_OK'}
		){
		my $node = $self->{'tree_ctrl'}->AppendItem($node,'Components',-1,-1);
	
		my $size = 0;
		
		foreach my $package (@{$config->{'packages'}}){
			++$index and next if defined $self->{'current_package'} and
				 $index < $self->{'current_package'}; 
			
			$self->{'current_package'} = $index++;

			if($package->Name eq 'Database Kernel'){
				if($^O =~ /mswin/i){
					$dependent_path = $package->MainPath->{'realname'};
				}
				else{
					$dependent_path = $package->MainPath->{'value'};
				}	
			}
			
			
			if(not defined $dependent_path and $package->IsSubPackage){
				my $parent_id = $package->ParentPackage();
				if(defined $parent_id and $parent_id->[0] eq 'Database Kernel'){
					if($^O =~ /mswin/i){
						$dependent_path = getRealPathName($parent_id->[1]);
					}
					else{
						$dependent_path = $parent_id->[1];
					}	
				}
			}
					
			if (${$package->Skip}){
				if(defined $package->{'skip_reason'}){
					my $node = $self->{'tree_ctrl'}->AppendItem($node,
								$package->DispName.' ['.$package->{'skip_reason'}.']',-1,-1);
					if(defined $package->{'skip_details'}){
							foreach my $key (sort keys(%{$package->{'skip_details'}})){
								$self->{'tree_ctrl'}->AppendItem($node,$key.': '.
														$package->{'skip_details'}->{$key},-1,-1);
							}	
					}	
				}
				next;				
			}

			$package_count++;
						
			if(defined $package->Size){
				$size += $package->Size;
			}
			
			if (defined $package->DbgSize){
				$size += $package->DbgSize;
			}
			
			my $size = '';
			if($package->Size > 0){
				my $bytes = $package->Size;
				if (defined $package->DbgSize){
					$bytes += $package->DbgSize;
				}
				$size = int(100 * $bytes / 1024 / 1024);
				$size =~ s/(\d\d)$/\.$1\ MB/;
				$size =~ s/^\./0\./;
				$size = ' ('.$size.')';	
			}
			
			my $node = $self->{'tree_ctrl'}->AppendItem($node,
								$package->DispName.$size,-1,-1);
			
			if($package->Update){
				$self->{'tree_ctrl'}->AppendItem($node,'Update: from '.
										$package->RegData->Version.
										' to '.$package->Version,-1,-1);		
			}
			else{
				$self->{'tree_ctrl'}->AppendItem($node,'Version: '.
												$package->Version,-1,-1);
			}
			if(defined $package->Mode){
				$self->{'tree_ctrl'}->AppendItem($node,'Object Mode: '.
													$package->Mode.' bit',-1,-1);
			}
			if(defined $package->BuildString){
				my $build_info = getBuildStringInfo($package->BuildString);		
				
				if(defined $build_info){
					$self->{'tree_ctrl'}->AppendItem($node,'Purpose: '.
													$build_info->{'purpose'},-1,-1);
					$self->{'tree_ctrl'}->AppendItem($node,'QA Level: '.
													$build_info->{'qa_level'},-1,-1);
					$self->{'tree_ctrl'}->AppendItem($node,'Make Type: '.
													$build_info->{'make_type'},-1,-1);
					$self->{'tree_ctrl'}->AppendItem($node,'Changelist ID: '.
													$build_info->{'changelist'},-1,-1);
									
				}
			
			}
			if(defined $package->MakeId){
				$self->{'tree_ctrl'}->AppendItem($node,'Make ID: '.
													$package->MakeId,-1,-1);
			}
			#$self->{'tree_ctrl'}->Expand($node);
			$self->{'tree_ctrl'}->SetItemBold($node,1);
		}
		
		if($size > 0){
			my $size_string = int(100 * $size / 1024 / 1024);
			$size_string =~ s/(\d\d)$/\.$1\ MB/;
			$size_string =~ s/^\./0\./;
			$size_string = ' ('.$size_string.')';	
			$self->{'tree_ctrl'}->SetItemText($node,'Components'.$size_string);	
		}	
		#$self->{'tree_ctrl'}->Expand($node);
		$self->{'tree_ctrl'}->SetItemBold($node,1);	
	}
	
	
	#
	#	software path
	#
	
	{
		my $node = $self->{'tree_ctrl'}->AppendItem($node,'Locations',-1,-1);
		my $path = $SAPDB::Install::Values::indep_prog_path;
		$path = getRealPathName($path) if ($^O =~ /mswin/i);		
		$self->{'tree_ctrl'}->AppendItem($node,'Independent Program Path: '.
							  $path,-1,-1);
		if(defined $dependent_path){
			$self->{'tree_ctrl'}->AppendItem($node,'Dependent Program Path: '.
									$dependent_path,-1,-1);
		}
		$path = $SAPDB::Install::Values::indep_data_path;
		$path = getRealPathName($path) if ($^O =~ /mswin/i);
		$self->{'tree_ctrl'}->AppendItem($node,'Independent Data Path: '.
							  $path,-1,-1);
		$self->{'tree_ctrl'}->Expand($node);
		$self->{'tree_ctrl'}->SetItemBold($node,1);	
	}


	if($package_count == 0 and not defined $config->{'container'}->Template and not defined $config->{'dbupdate'}){
		$self->GetWizard->{'nbutton_disabled'} = 1;
	}


	#
	#	user / group
	#
	
	unless($^O =~ /mswin/i){
		my $node = $self->{'tree_ctrl'}->AppendItem($node,'Operating System User and Group',-1,-1);
		$self->{'tree_ctrl'}->AppendItem($node,'Software Owner: '.$SAPDB::Install::Values::owner,-1,-1);
		$self->{'tree_ctrl'}->AppendItem($node,'Administrators Group: '.$SAPDB::Install::Values::group,-1,-1);
		$self->{'tree_ctrl'}->Expand($node);
		$self->{'tree_ctrl'}->SetItemBold($node,1);	
	}

	$self->{'tree_ctrl'}->Expand($node);
	$self->{'tree_ctrl'}->Expand($self->{'root_node'});
	$self->GetSizer->Add($self->{'tree_ctrl'},1,wxEXPAND | wxALL,20);
	$self->SetAutoLayout(1);
	$self->Layout;
	$self->{'activated'} = 1;
	return undef;
}

sub Back{
	my ($self) = @_;
	$self->GetWizard->SetInstallMode(0);
	delete $self->{'activated'};
	delete $self->GetWizard->{'nbutton_disabled'};
	if($self->{'initialized'}){
		while($self->GetSizer->Remove(0)){}
		$self->{'tree_ctrl'}->Destroy;
		delete $self->{'tree_ctrl'};
		delete $self->{'initialized'};
	}
	return 1;
}


sub Destroy{
	my ($self) = @_;
	if(defined $self->GetSizer){
			while($self->GetSizer->Remove(0)){};
	}
	if(defined $self->{'tree_ctrl'}){
		$self->{'tree_ctrl'}->Destroy;
		delete $self->{'tree_ctrl'};
	}
	$self->SUPER::Destroy;
}

sub DESTROY{
	my ($self) = @_;
	print ">>>> destroying $self\n"
		if $SAPDB::Install::DEBUG::DESTRUCT;
}


1;

==> maxdb-all-sun-64bit-sparc-7_6_00_34.tgz: SAPDB/Install/Wizard/Dialog/Summary.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V76/c_00/b_34/sys/src/install/perl/SAPDB/Install/Wizard/Dialog/Summary.pm#1 $
# $DateTime: 2006/09/04 17:37:38 $
# $Change: 134683 $
#
# Desc: Installation summary 
# 
#

package SAPDB::Install::Wizard::Dialog::Summary;

use Wx qw (
	wxALL wxVERTICAL wxEXPAND);

use SAPDB::Install::Tools;

use base SAPDB::Install::Wizard::Dialog::Base;


sub new {
	my ($this) = shift->SUPER::new(@_);
	return $this;
}



sub init{
	my ($self,$config) = @_;
	my $sizer = Wx::BoxSizer->new(wxVERTICAL);
	$self->SetSizer($sizer);
	$self->{'initialized'} = 1;
	return {'auto_next' => 1};
}


sub Process{
	my ($self,$config) = @_;
	return {} if $self->{'activated'};
	$self->{'current_package'} = undef;
	$self->GetWizard->SetInstallMode(1);
	$self->{'tree_ctrl'} = Wx::TreeCtrl->new($self,-1,[0,0],[350,300]);
	my $index = 0;
	$self->{'root_node'} = $self->{'tree_ctrl'}->AddRoot('MaxDB Installation',-1,-1);
	$self->{'tree_ctrl'}->SetItemBold($self->{'root_node'},1);

	#
	#	Database Settings
	#	
	
	if(defined $config->{'container'}->Template){
		my $node = $self->{'tree_ctrl'}->AppendItem($self->{'root_node'},'Database ['.
		$config->{'container'}->Template->getDBInstance()->getDBName().']',-1,-1);
		$self->{'tree_ctrl'}->SetItemBold($node,1);
		foreach my $frame (@{$config->{'container'}->Template->createTemplateOverView}){
			my $node = $self->{'tree_ctrl'}->AppendItem($node,$frame->{'Title'},-1,-1);				
			$self->{'tree_ctrl'}->SetItemBold($node,1);
			foreach my $param (sort { $frame->{'Data'}->{$a}->{'ControlType'}->{'priority'} <=>
									  $frame->{'Data'}->{$b}->{'ControlType'}->{'priority'} }
							   keys(%{$frame->{'Data'}})){
					
					
					my $value = &{$frame->{'Data'}->{$param}->{'Getter'}};
					if($frame->{'Data'}->{$param}->{'ControlType'}->{'id'} eq 'pagesType' ||
						$frame->{'Data'}->{$param}->{'ControlType'}->{'unit'} eq 'pages'){
						$value = (int ($value * 8 / 1024)).' MB';
					}
					elsif($frame->{'Data'}->{$param}->{'ControlType'}->{'id'} eq 'booleanType'){
						$value = ($value ? 'On' : 'Off');
					}
					
					my $node = $self->{'tree_ctrl'}->AppendItem($node,$frame->{'Data'}->{$param}->{'Label'}.': '.
													$value,-1,-1);				
					
					#my %desc = (
					#				'label' => $frame->{'Data'}->{$param}->{'Label'},
					#				'value' => &{$frame->{'Data'}->{$param}->{'Getter'}},
					#				'desc'  => $frame->{'Data'}->{$param}->{'Description'}
					#			);
			}
			$self->{'tree_ctrl'}->Expand($node) if $frame->{'SummaryExpand'};	
		}
		$self->{'tree_ctrl'}->Expand($node);
	}
	elsif(defined $config->{'dbupdate'}){
		my $node = $self->{'tree_ctrl'}->AppendItem($self->{'root_node'},'Update Database ['.
		$config->{'dbupdate'}->{'dbname'}.']',-1,-1);
		$self->{'tree_ctrl'}->SetItemBold($node,1);
		if(defined $config->{'dbupdate'}->{'registry_instancedata'}){
			foreach my $param (sort keys(%{$config->{'dbupdate'}->{'registry_instancedata'}})){
				next if $param =~ /INSTANCE_CHECK/;
				my $value = $config->{'dbupdate'}->{'registry_instancedata'}->{$param};
				if($param =~ /OK/){
					if($value){
						$value = 'yes';
					}
					else{
						$value = 'no';
					}
				}
				elsif($value !~ /\S/){
					next;	
				}
				if($param =~ /SOFTWARE_OK/){
					$param = 'Software already installed';
				}
				if($param =~ /^TYPE$/){
					$param = 'Database Type';
				}									
				$param =~ s/_/\ /g;
				$param =~ tr/A-Z/a-z/;
				$param =~ s/^(\w)/\u$1/g;
				$param =~ s/\s(\w)/\ \u$1/g;
				
				my $node = $self->{'tree_ctrl'}->AppendItem($node,$param.': '.
							$value,-1,-1);		
			}
			
		}
		
	}

	my $node = $self->{'tree_ctrl'}->AppendItem($self->{'root_node'},'Software',-1,-1);
	$self->{'tree_ctrl'}->SetItemBold($node,1);

	
	#
	#	software components
	#
	
	my $dependent_path;

	my $package_count = 0;

	unless(defined $config->{'dbupdate'} and
		defined $config->{'dbupdate'}->{'registry_instancedata'} and 
		$config->{'dbupdate'}->{'registry_instancedata'}->{'SOFTWARE_OK'}
		){
		my $node = $self->{'tree_ctrl'}->AppendItem($node,'Components',-1,-1);
	
		my $size = 0;
		
		foreach my $package (@{$config->{'packages'}}){
			++$index and next if defined $self->{'current_package'} and
				 $index < $self->{'current_package'}; 
			
			$self->{'current_package'} = $index++;

			if($package->Name eq 'Database Kernel'){
				if($^O =~ /mswin/i){
					$dependent_path = $package->MainPath->{'realname'};
					unless ($dependent_path =~ /\S/){
						$dependent_path = getRealPathName($package->MainPath->{'value'});
					}
				}
				else{
					$dependent_path = $package->MainPath->{'value'};
				}	
			}
			
			
			if(not defined $dependent_path and $package->IsSubPackage){
				my $parent_id = $package->ParentPackage();
				if(defined $parent_id and $parent_id->[0] eq 'Database Kernel'){
					if($^O =~ /mswin/i){
						$dependent_path = getRealPathName($parent_id->[1]);
					}
					else{
						$dependent_path = $parent_id->[1];
					}	
				}
			}
					
			if (${$package->Skip}){
				if(defined $package->{'skip_reason'}){
					my $node = $self->{'tree_ctrl'}->AppendItem($node,
								$package->DispName.' ['.$package->{'skip_reason'}.']',-1,-1);
					if(defined $package->{'skip_details'}){
							foreach my $key (sort keys(%{$package->{'skip_details'}})){
								$self->{'tree_ctrl'}->AppendItem($node,$key.': '.
														$package->{'skip_details'}->{$key},-1,-1);
							}	
					}	
				}
				next;				
			}

			$package_count++;
						
			if(defined $package->Size){
				$size += $package->Size;
			}
			
			if (defined $package->DbgSize){
				$size += $package->DbgSize;
			}
			
			my $size = '';
			if($package->Size > 0){
				my $bytes = $package->Size;
				if (defined $package->DbgSize){
					$bytes += $package->DbgSize;
				}
				$size = int(100 * $bytes / 1024 / 1024);
				$size =~ s/(\d\d)$/\.$1\ MB/;
				$size =~ s/^\./0\./;
				$size = ' ('.$size.')';	
			}
			
			my $node = $self->{'tree_ctrl'}->AppendItem($node,
								$package->DispName.$size,-1,-1);
			
			if($package->Update){
				$self->{'tree_ctrl'}->AppendItem($node,'Update: from '.
										$package->RegData->Version.
										' to '.$package->Version,-1,-1);		
			}
			else{
				$self->{'tree_ctrl'}->AppendItem($node,'Version: '.
												$package->Version,-1,-1);
			}
			if(defined $package->Mode){
				$self->{'tree_ctrl'}->AppendItem($node,'Object Mode: '.
													$package->Mode.' bit',-1,-1);
			}
			if(defined $package->BuildString){
				my $build_info = getBuildStringInfo($package->BuildString);		
				
				if(defined $build_info){
					$self->{'tree_ctrl'}->AppendItem($node,'Purpose: '.
													$build_info->{'purpose'},-1,-1);
					$self->{'tree_ctrl'}->AppendItem($node,'QA Level: '.
													$build_info->{'qa_level'},-1,-1);
					$self->{'tree_ctrl'}->AppendItem($node,'Make Type: '.
													$build_info->{'make_type'},-1,-1);
					$self->{'tree_ctrl'}->AppendItem($node,'Changelist ID: '.
													$build_info->{'changelist'},-1,-1);
									
				}
			
			}
			if(defined $package->MakeId){
				$self->{'tree_ctrl'}->AppendItem($node,'Make ID: '.
													$package->MakeId,-1,-1);
			}
			#$self->{'tree_ctrl'}->Expand($node);
			$self->{'tree_ctrl'}->SetItemBold($node,1);
		}
		
		if($size > 0){
			my $size_string = int(100 * $size / 1024 / 1024);
			$size_string =~ s/(\d\d)$/\.$1\ MB/;
			$size_string =~ s/^\./0\./;
			$size_string = ' ('.$size_string.')';	
			$self->{'tree_ctrl'}->SetItemText($node,'Components'.$size_string);	
		}	
		#$self->{'tree_ctrl'}->Expand($node);
		$self->{'tree_ctrl'}->SetItemBold($node,1);	
	}
	
	
	#
	#	software path
	#
	
	{
		my $node = $self->{'tree_ctrl'}->AppendItem($node,'Locations',-1,-1);
		
		if (exists $SAPDB::Install::Config{'SDB_PORTABLE_ROOT'}){
			my $path = $SAPDB::Install::Config{'SDB_PORTABLE_ROOT'};
			$path = getRealPathName($path) if ($^O =~ /mswin/i);
			$self->{'tree_ctrl'}->AppendItem($node,'Portable Root Path: '.
									$path,-1,-1);
			if (exists $SAPDB::Install::Config{'SDB_PORTABLE_PROGRAMS_ROOT'}){
				$path = $SAPDB::Install::Config{'SDB_PORTABLE_PROGRAMS_ROOT'};
				$path = getRealPathName($path) if ($^O =~ /mswin/i);
				$self->{'tree_ctrl'}->AppendItem($node,'Portable Program Root Path: '.
									$path,-1,-1);
			}									
		}
				
		my $path = $SAPDB::Install::Values::indep_prog_path;
		$path = getRealPathName($path) if ($^O =~ /mswin/i);		
		$self->{'tree_ctrl'}->AppendItem($node,'Independent Program Path: '.
							  $path,-1,-1);
		if(defined $dependent_path){
			$self->{'tree_ctrl'}->AppendItem($node,'Dependent Path: '.
									$dependent_path,-1,-1);
		}
		$path = $SAPDB::Install::Values::indep_data_path;
		$path = getRealPathName($path) if ($^O =~ /mswin/i);
		
		$self->{'tree_ctrl'}->AppendItem($node,'Independent Data Path: '.
							  $path,-1,-1);
		$self->{'tree_ctrl'}->Expand($node);
		$self->{'tree_ctrl'}->SetItemBold($node,1);	
	}


	if($package_count == 0 and not defined $config->{'container'}->Template and not defined $config->{'dbupdate'}){
		$self->GetWizard->{'nbutton_disabled'} = 1;
	}


	#
	#	user / group
	#
	
	unless($^O =~ /mswin/i){
		my $node = $self->{'tree_ctrl'}->AppendItem($node,'Operating System User and Group',-1,-1);
		$self->{'tree_ctrl'}->AppendItem($node,'Software Owner: '.$SAPDB::Install::Values::owner,-1,-1);
		$self->{'tree_ctrl'}->AppendItem($node,'Administrators Group: '.$SAPDB::Install::Values::group,-1,-1);
		$self->{'tree_ctrl'}->Expand($node);
		$self->{'tree_ctrl'}->SetItemBold($node,1);	
	}

	$self->{'tree_ctrl'}->Expand($node);
	$self->{'tree_ctrl'}->Expand($self->{'root_node'});
	$self->GetSizer->Add($self->{'tree_ctrl'},1,wxEXPAND | wxALL,20);
	$self->SetAutoLayout(1);
	$self->Layout;
	$self->{'activated'} = 1;
	return undef;
}

sub Back{
	my ($self) = @_;
	$self->GetWizard->SetInstallMode(0);
	delete $self->{'activated'};
	delete $self->GetWizard->{'nbutton_disabled'};
	if($self->{'initialized'}){
		while($self->GetSizer->Remove(0)){}
		$self->{'tree_ctrl'}->Destroy;
		delete $self->{'tree_ctrl'};
		delete $self->{'initialized'};
	}
	return 1;
}


sub Destroy{
	my ($self) = @_;
	if(defined $self->GetSizer){
			while($self->GetSizer->Remove(0)){};
	}
	if(defined $self->{'tree_ctrl'}){
		$self->{'tree_ctrl'}->Destroy;
		delete $self->{'tree_ctrl'};
	}
	$self->SUPER::Destroy;
}

sub DESTROY{
	my ($self) = @_;
	print ">>>> destroying $self\n"
		if $SAPDB::Install::DEBUG::DESTRUCT;
}


1;
